@@ -8,6 +8,7 @@ import requests
 
 import marquez_client
 
+from typing import Optional
 from deprecation import deprecated
 from six.moves.urllib.parse import quote
 
@@ -71,6 +72,19 @@ class MarquezClient:
             }
         )
 
+    def list_events(self, namespace: Optional[str] = None, limit=None, offset=None):
+        url = '/events'
+        if namespace:
+            url = f'/events/{namespace}'
+
+        return self._get(
+            self._url(url),
+            params={
+                'limit': limit or DEFAULT_LIMIT,
+                'offset': offset or DEFAULT_OFFSET
+            }
+        )
+
     @deprecated(deprecated_in='0.20.0', removed_in='0.25.0',
                 details='Use OpenLineage instead, see `https://openlineage.io`')
     def create_source(self, source_name, source_type, connection_url,
